{
  Copyright (c) 2020, 2021 Frank Fischer <frank-fischer@shadow-soft.de>

  This program is free software: you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
  published by the Free Software Foundation, either version 3 of the
  License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see  <http://www.gnu.org/licenses/>
}

unit tests.csvwriter;

{$mode objfpc}{$H+}
{$modeswitch typehelpers}

interface

uses fpcunit, testregistry, EasyCSV;

type
   TTestCSVWriter = class(TTestCase)
   private
      Fwriter : TCSVWriter;

   published
      procedure Test_AddRow;
      procedure Test_AddCells;
      procedure Test_Quote;

   protected
      procedure Setup; override;
      procedure TearDown; override;
   end;

implementation

uses Classes;

procedure TTestCSVWriter.Setup;
begin
   Fwriter := TCSVWriter.Create;
end;

procedure TTestCSVWriter.TearDown;
begin
   Fwriter.Free;
end;

procedure TTestCSVWriter.Test_AddRow;
var
   s : TStringStream = nil;
begin
   try
      s := TStringStream.Create('');
      Fwriter.Output := s;
      Fwriter.LineEnding := ';';
      Fwriter.AddRow(['A', 'B', 'C']);
      Fwriter.AddRow([1, 2, 3]);
      Fwriter.AddRow([4, 5, 6]);
      AssertEquals('A,B,C;1,2,3;4,5,6;', s.DataString);
   finally
      s.Free
   end
end;

procedure TTestCSVWriter.Test_AddCells;
var
   s : TStringStream = nil;
begin
   try
      s := TStringStream.Create('');
      Fwriter.Output := s;
      Fwriter.LineEnding := ';';
      Fwriter.AddCells(['A']);
      Fwriter.AddCells(['B', 'C']);
      Fwriter.EndRow;
      Fwriter.AddCells([1, 2]);
      Fwriter.AddCells([3]);
      Fwriter.EndRow;
      Fwriter.AddCells([4,5,6]);
      Fwriter.EndRow;
      AssertEquals('A,B,C;1,2,3;4,5,6;', s.DataString);
   finally
      s.Free
   end
end;

procedure TTestCSVWriter.Test_Quote;
var
   s : TStringStream = nil;
begin
   try
      s := TStringStream.Create('');
      Fwriter.Output := s;
      Fwriter.LineEnding := ';';
      Fwriter.AddRow(['  A  ', '"B"', 'C,D']);
      Fwriter.AddRow([1, ';2;', 3]);
      Fwriter.AddRow([4, 5, '   ,6;"7", ']);
      AssertEquals('"  A  ","""B""","C,D";1,";2;",3;4,5,"   ,6;""7"", ";', s.DataString);
   finally
      s.Free
   end
end;

begin
   RegisterTest(TTestCSVWriter);
end.
